@@ -38,7 +38,7 @@ public:
     KCMAkregatorGeneralConfig(QWidget *parent, const QVariantList &args);
 
 private:
-    QWidget *m_widget;
+    QWidget *m_widget = nullptr;
 };
 
 #endif // AKREGATOR_CONFIG_GENERAL_H
