@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ class AKREGATOR_EXPORT MainFrame : public Frame
 public:
 
     explicit MainFrame(QWidget *parent, QWidget *widget);
-    virtual ~MainFrame();
+    ~MainFrame() override;
 
     QUrl url() const override;
 
